struct PasswordGeneratorOptions {
lower: (CharSet, usize),
upper: (CharSet, usize),
number: (CharSet, usize),
special: (CharSet, usize),
custom: (CharSet, usize),
all: (CharSet, usize),
length: usize,
max_consecutive: Option<usize>,
}Expand description
Represents a set of valid options to generate a password with.
To get an instance of it, use
PasswordGeneratorRequest::validate_options
Fields
lower: (CharSet, usize)upper: (CharSet, usize)number: (CharSet, usize)special: (CharSet, usize)custom: (CharSet, usize)Custom required characters from passwordrules required: [...] entries. At least one
char from this set is guaranteed to appear in the output when the set is non-empty.
all: (CharSet, usize)length: usizemax_consecutive: Option<usize>Maximum number of consecutive identical characters allowed in the output. None
disables the check. Validated to be >= 1 in
PasswordGeneratorRequest::validate_options.